## Spec file for l2tpd
## Layer 2 Tunnelling Protocol Daemon (RFC 2661)

Summary: Layer 2 Tunnelling Protocol Daemon (RFC 2661)
Name: l2tpd
Version: 0.69cvs20051030
Vendor: Damion de Soto <damion@snapgear.com>
# Original packagers: Lenny Cartier <lenny@mandrakesoft.com>
# and Per yvind Karlsen <peroyvind@delonic.no>
Packager: Jacco de Leeuw <jacco2@dds.nl>
Release: 1jdl
License: GPL
Url: http://%{name}.sourceforge.net
Group: System/Servers

%define freeswanconfigpath freeswan
%define openswanconfigpath openswan
%define strongswanconfigpath strongswan
%define ipsecconfigpath ipsec.d

# Are you building on SuSE?
# Set here (1=yes 0=no):
%define suse 0

# Do you want to use Unix98-style ptys? (FC2+, MDK10.1+)?
# Or do you want to use BSD-style ptys? (Most other distributions)
# BSD-style ptys were the default for all versions before 11jdl.
%define unix98pty 1

# I do not convert the upstream tarball from .gz to .bz2 because l2tpd
# is a remote access daemon and security conscious people might want to
# verify its signature against tampering.
Source0: http://prdownloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
#Source1: %{name}-%{version}.tar.gz.sig
Source2: %{name}.init
Source3: %{name}-RPM.README
# Minimal sample configuration file for use with Openswan
Source4: %{name}.conf
Source5: %{name}-options.l2tpd
Source11: %{name}-chapsecrets.sample
# Four sample Openswan configuration files
Source6: %{name}-L2TP-PSK.conf
Source7: %{name}-L2TP-CERT.conf
Source8: %{name}-L2TP-PSK-orgWIN2KXP.conf
Source9: %{name}-L2TP-CERT-orgWIN2KXP.conf
# /etc/rc.d init script for SuSE by Bernhard Thoni
Source10: %{name}-suse.init

# Unix 98 pty patch by Nasim Mansurov / Iosif Peterfi. Code from rp-l2tp
# was used. You may have to use this patch because some Linus distributions
# no longer support BSD-style ptys. The Linux kernel config help files also
# say that Unix98 ptys are "safer" and use up less memory. On the other
# hand, Unix98-style ptys may not be available on some (embedded) platforms
Patch12: %{name}-pty-Unix98.patch5
# Fixes some small errors so that the thing at least compiles on Solaris
Patch13: %{name}-Solaris.patch4
# Workaround for a StopCCN disconnect bug in the MSL2TP client
# Thanks to Robert Vogelgesang for bringing to my attention that
# the original patch was incorrect.
Patch17: %{name}-MSL2TP-StopCCN.patch4
# Patch by Paul Wouters, fixes compile problem under GCC 4 (uaddr static)
# (e.g. FC4+ and Mandrake 10.2+).
Patch19: %{name}-log.patch2

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
Requires: ppp
%if ! %{suse}
Requires: initscripts chkconfig
%else
Requires: aaa_base
%define _initrddir /etc/init.d
%endif

%description
l2tpd is an implementation of the Layer 2 Tunnelling Protocol (RFC 2661).
L2TP allows you to tunnel PPP over UDP. Some ISPs use L2TP to tunnel user
sessions from dial-in servers (modem banks, ADSL DSLAMs) to back-end PPP
servers. Another important application is Virtual Private Networks where
the IPsec protocol is used to secure the L2TP connection (L2TP/IPsec,
RFC 3193). The L2TP/IPsec protocol is mainly used by Windows and 
Mac OS X clients. On Linux, l2tpd can be used in combination with IPsec
implementations such as FreeS/WAN, Openswan, Strongswan and KAME.
Example configuration files for such setup with Openswan are included
in this RPM.

l2tpd works by opening a pseudo-tty for communicating with pppd.
It runs completely in userspace.

Based on the Mandriva RPM by Lenny Cartier <lenny@mandrivasoft.com>
and Per yvind Karlsen <peroyvind@delonic.no>
%prep
%setup -q
%if %{unix98pty}
%patch12 -p0 -b .unix98pty
%endif
%patch13 -p0 -b .gccsol
%patch17 -p0 -b .stopconnection
%patch19 -p1 -b .uaddrfix
%if %{suse}
cp -p %{SOURCE10} .
%else
cp -p %{SOURCE2} .
%endif
cp -p %{SOURCE3} RPM.README

%build
# %make is not available on all distributions?
make DFLAGS="$RPM_OPT_FLAGS -g -DDEBUG_PPPD -DDEBUG_CONTROL -DDEBUG_ENTROPY"

%install
# There's no 'install' rule in the Makefile, so let's do it manually
install -d %{buildroot}%{_sbindir}
install -m755 %{name} %{buildroot}%{_sbindir}
install -d %{buildroot}%{_mandir}/{man5,man8}
install -m644 doc/%{name}.conf.5 %{buildroot}%{_mandir}/man5
install -m644 doc/l2tp-secrets.5 %{buildroot}%{_mandir}/man5/
install -m644 doc/%{name}.8 %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_sysconfdir}/{%{name},ppp,%{ipsecconfigpath}}
install -m644 doc/%{name}.conf.sample %{buildroot}%{_sysconfdir}/%{name}/
install -m644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -m644 %{SOURCE5} %{buildroot}%{_sysconfdir}/ppp/options.l2tpd
install -m644 %{SOURCE6} %{buildroot}%{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK.conf
install -m644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT.conf
install -m644 %{SOURCE8} %{buildroot}%{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK-orgWIN2KXP.conf
install -m644 %{SOURCE9} %{buildroot}%{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT-orgWIN2KXP.conf
install -m600 doc/l2tp-secrets.sample %{buildroot}%{_sysconfdir}/%{name}/l2tp-secrets
install -m600 %{SOURCE11} %{buildroot}%{_sysconfdir}/ppp/chap-secrets.sample
install -d %{buildroot}%{_initrddir}
%if %{suse}
install -m755 %{SOURCE10} %{buildroot}%{_initrddir}/%{name}
ln -s ../../%{_initrddir}/%{name} %{buildroot}%{_sbindir}/rc%{name}
%else
install -m755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
%endif

%post
# For security reasons l2tpd is not started when the RPM is installed
# or at boot time. To start l2tpd manually, use:
#   /sbin/service l2tpd start
# To start l2tpd at boot time, use:
#   /sbin/chkconfig --level 345 l2tpd on 
#
# The Mandriva RPMs for Openswan, Strongswan and FreeS/WAN do not use
# /etc/ipsec.d/ for some reason. The symbolic links below are a workaround.
# (Probably should test for existence instead of forced creation after making
# a backup copy).
if [ -d %{_sysconfdir}/%{freeswanconfigpath} ]; then
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK.conf %{_sysconfdir}/%{freeswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT.conf %{_sysconfdir}/%{freeswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK-orgWIN2KXP.conf %{_sysconfdir}/%{freeswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT-orgWIN2KXP.conf %{_sysconfdir}/%{freeswanconfigpath}
fi
if [ -d %{_sysconfdir}/%{openswanconfigpath} ]; then
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK.conf %{_sysconfdir}/%{openswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT.conf %{_sysconfdir}/%{openswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK-orgWIN2KXP.conf %{_sysconfdir}/%{openswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT-orgWIN2KXP.conf %{_sysconfdir}/%{openswanconfigpath}
fi
if [ -d %{_sysconfdir}/%{strongswanconfigpath} ]; then
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK.conf %{_sysconfdir}/%{strongswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT.conf %{_sysconfdir}/%{strongswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-PSK-orgWIN2KXP.conf %{_sysconfdir}/%{strongswanconfigpath}
  ln -sfb %{_sysconfdir}/%{ipsecconfigpath}/L2TP-CERT-orgWIN2KXP.conf %{_sysconfdir}/%{strongswanconfigpath}
fi

%preun
# Don't leave the daemon running at uninstall.
if [ -f /var/run/%{name}.pid ]; then
  %if ! %{suse}
    /sbin/service %{name} stop > /dev/null 2>&1
  %else
    /usr/sbin/rcl2tpd stop > /dev/null 2>&1
  %endif
fi
if [ "$1" -eq "0" ]
then
  /sbin/chkconfig --del %{name} > /dev/null 2>&1
fi
exit 0;

%postun
if [ "$1" -ge "1" ]; then
%if ! %{suse}
  /sbin/service %{name} try-restart > /dev/null 2>&1
%else
  /usr/sbin/rcl2tpd try-restart > /dev/null 2>&1
%endif
fi
exit 0;

%clean

%files
%defattr(-,root,root)
%doc BUGS CHANGELOG CREDITS LICENSE README TODO doc/rfc2661.txt RPM.README
%{_sbindir}/%{name}
%{_mandir}/*/*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/ppp/*
%dir %{_sysconfdir}/%{ipsecconfigpath}
%config(noreplace) %{_sysconfdir}/%{ipsecconfigpath}/*
%attr(0755,root,root) %{_initrddir}/%{name}
%if %{suse}
%config(noreplace) %{_sbindir}/rc%{name}
%endif

%changelog
* Tue Nov 1 2005 Jacco de Leeuw <jacco2@dds.nl> 0.690.69cvs20051030-1jdl
- Checked out l2tpd from SourceForge CVS. This got rid of a lot of patches!
  Thanks to current l2tpd team members Robert Vogelgesang and Damion de Soto.
- Merged changes by Paul Wouters.
- Choosing between Unix98 or BSD-style ptys is now configurable through
  a compile-time define "UNIX98PTYS" (after applying the required patch).
- Unix98-style ptys are the default now.

* Wed Oct 5 2005 Jacco de Leeuw <jacco2@dds.nl> 0.69-13jdl
- Notified by Robert Vogelgesang that patch9 is incorrect.
  It is not l2tpd that is broken, it is the MSL2TP client that is
  sending incorrect StopCCN messages. So now the original behaviour is 
  restored. A workaround has been made for the broken MSL2TP client.
  Patch9 replaced with patch17.

* Sat Jun 4 2005 Jacco de Leeuw <jacco2@dds.nl>
- l2tpd.org domain has been hijacked. Project moved back to SourceForge:
  http://l2tpd.sourceforge.net 

* Tue May 3 2005 Jacco de Leeuw <jacco2@dds.nl>
- Small Makefile fixes. Explicitly use gcc instead of cc. 
  Network services library was not linked on Solaris due to typo.

* Fri Feb 4 2005 Jacco de Leeuw <jacco2@dds.nl>
- Added code from Roaring Penguin (rp-l2tp) to support Unix98-style ptys.
  Requires the N_HDLC kernel module. 

* Tue Nov 9 2004 Jacco de Leeuw <jacco2@dds.nl> 0.69-10jdl
- [SECURITY FIX] Added fix from Debian because of a bss-based
  buffer overflow.
  (http://www.mail-archive.com/l2tpd-devel@l2tpd.org/msg01071.html)
- Mandriva's FreeS/WAN, Openswan and Strongswan RPMS use configuration
  directories /etc/{freeswan,openswan,strongswan}. Install our
  configuration files to /etc/ipsec.d and create symbolic links in
  those directories.

* Tue Aug 18 2004 Jacco de Leeuw <jacco2@dds.nl>
- Removed 'leftnexthop=' lines. Not relevant for recent versions
  of FreeS/WAN and derivates.

* Tue Jan 20 2004 Jacco de Leeuw <jacco2@dds.nl>  0.69-9jdl
- Added "noccp" because of too much MPPE/CCP messages sometimes.

* Sat Aug 23 2003 Jacco de Leeuw <jacco2@dds.nl>
- MTU/MRU 1410 seems to be the lowest possible for MSL2TP.
  For Windows 2000/XP it doesn't seem to matter.
- Typo in l2tpd.conf (192.168.128/25).

* Thu Jul 20 2003 Jacco de Leeuw <jacco2@dds.nl>  0.69-7jdl
- Added the "listen-addr" global parameter for l2tpd.conf. By
  default, the daemon listens on *all* interfaces. Use
  "listen-addr" if you want it to bind to one specific
  IP address (interface), for security reasons. (See also:
  http://www.jacco2.dds.nl/networking/freeswan-l2tp.html#Firewallwarning)
- Explained in l2tpd.conf that two different IP addresses should be
  used for 'listen-addr' and 'local ip'.
- Modified init script. Upgrades should work better now. You
  still need to start/chkconfig l2tpd manually.
- Renamed the example Openswan .conf files to better reflect
  the situation. There are two variants using different portselectors.
  Previously I thought Windows 2000/XP used portselector 17/0
  and the rest used 17/1701. But with the release of an updated 
  IPsec client by Microsoft, it turns out that 17/0 must have
  been a mistake: the updated client now also uses 17/1701.

* Thu Mar 13 2003 Bernhard Thoni <tech-role@tronicplanet.de>
- Adjustments for SuSE8.x (thanks, Bernhard!)
- Added sample chap-secrets.

* Wed Feb 26 2003 Jacco de Leeuw <jacco2@dds.nl> 0.69-4jdl
- Seperate example config files for Win9x (MSL2TP) and Win2K/XP
  due to left/rightprotoport differences.
  Fixing preun for Red Hat.

* Sun Nov 10 2002 Jacco de Leeuw <jacco2@dds.nl>
- Specfile adapted from Mandriva Cooker. 

* Mon Oct 21 2002 Lenny Cartier <lenny@mandrakesoft.com> 0.69-3mdk
- from Per yvind Karlsen <peroyvind@delonic.no> :

* Thu Oct 17 2002 Per yvind Karlsen <peroyvind@delonic.no> 0.69-1mdk
- Initial release
